@@ -6,14 +6,16 @@ import numpy as np
 
 from Orange.data import TimeVariable, Table
 from Orange.widgets import widget, gui, settings
-from Orange.widgets.highcharts import Highchart
+from Orange.widgets.widget import Input
 
-from PyQt4.QtGui import QTreeWidget, QSizePolicy, \
-    QWidget, QPushButton, QIcon, QListView, QVBoxLayout
-from PyQt4.QtCore import Qt, QSize, pyqtSignal, QTimer
+from AnyQt.QtWidgets import QTreeWidget, \
+    QWidget, QPushButton, QListView, QVBoxLayout
+from AnyQt.QtGui import QIcon
+from AnyQt.QtCore import QSize, pyqtSignal, QTimer
 
 from Orange.widgets.utils.itemmodels import VariableListModel
 from orangecontrib.timeseries import Timeseries
+from orangecontrib.timeseries.widgets.highcharts import Highchart
 
 
 class PlotConfigWidget(QWidget, gui.OWComponent):
@@ -80,6 +82,7 @@ class PlotConfigWidget(QWidget, gui.OWComponent):
         selection = [mi.model()[mi.row()]
                      for mi in self.view.selectionModel().selectedIndexes()]
         self.sigSelection.emit(self.ax, selection)
+        self.sigType.emit(self.ax, self.plot_type)
 
 
 class Highstock(Highchart):
@@ -91,7 +94,8 @@ class Highstock(Highchart):
                          yAxis_labels_y=-3,
                          yAxis_labels_align_x='right',
                          yAxis_title_text=None,
-                         plotOptions_series_dataGrouping_groupPixelWidth=7,
+                         plotOptions_series_dataGrouping_groupPixelWidth=2,
+                         plotOptions_series_dataGrouping_approximation='high',
                          plotOptions_areasplinerange_states_hover_lineWidthPlus=0,
                          plotOptions_areasplinerange_tooltip_pointFormat='''
                             <span style="color:{point.color}">\u25CF</span>
@@ -158,10 +162,9 @@ class Highstock(Highchart):
         ci_percents = []
 
         data = self.parent.data
-        delta = data.time_delta if isinstance(data.time_variable, TimeVariable) else None
 
         for attr in series:
-            newseries.append(np.ravel(data[:, attr]))
+            newseries.append(data.get_column_view(attr)[0])
             names.append(attr.name)
             deltas.append(None)
             forecasts.append(None)
@@ -192,7 +195,7 @@ class Highstock(Highchart):
                 tvals = data.time_values
 
                 if isinstance(delta, Number):
-                    deltas[-1] = (tvals[0] * 1000, tvals[-1] * 1000, delta, None)
+                    deltas[-1] = (tvals[0] * 1000, tvals[-1] * 1000, delta * 1000, None)
                 elif delta:
                     deltas[-1] = (tvals[0] * 1000, tvals[-1] * 1000) + delta
                 else:
@@ -313,15 +316,6 @@ class Highstock(Highchart):
             chart.redraw(false);
         ''' % locals())
 
-    def enable_rangeSelector(self, enable):
-        display = 'initial' if enable else 'none'
-        self.evalJS(
-            '$(".highcharts-range-selector-buttons, '
-            '   .highcharts-input-group").css({display: "%s"});' % display)
-        # Reset the range selector to full view
-        if not enable:
-            self.evalJS('$(chart.rangeSelector.buttons[5]).click();')
-
 
 class OWLineChart(widget.OWWidget):
     name = 'Line Chart'
@@ -329,11 +323,14 @@ class OWLineChart(widget.OWWidget):
     icon = 'icons/LineChart.svg'
     priority = 90
 
-    inputs = [("Time series", Table, 'set_data'),
-              ('Forecast', Timeseries, 'set_forecast', widget.Multiple)]
+    class Inputs:
+        time_series = Input("Time series", Table)
+        forecast = Input("Forecast", Timeseries, multiple=True)
 
     attrs = settings.Setting({})  # Maps data.name -> [attrs]
 
+    graph_name = 'chart'
+
     def __init__(self):
         self.data = None
         self.plots = []
@@ -349,7 +346,14 @@ class OWLineChart(widget.OWWidget):
         # TODO: allow selecting ranges that are sent to output as subset table
         self.chart = highstock = Highstock(self, highchart='StockChart')
         self.mainArea.layout().addWidget(highstock)
-        highstock.chart()
+        # highstock.evalJS('Highcharts.setOptions({navigator: {enabled:false}});')
+        highstock.chart(
+            # For some reason, these options don't work as global opts applied at Highstock init time
+            # Disable top range selector
+            rangeSelector_enabled=False,
+            rangeSelector_inputEnabled=False,
+            # Disable bottom miniview navigator (it doesn't update)
+            navigator_enabled=False, )
         QTimer.singleShot(0, self.add_plot)
 
     def add_plot(self):
@@ -367,6 +371,7 @@ class OWLineChart(widget.OWWidget):
         self.add_button.setDisabled(len(self.configs) >= 5)
         self.configsArea.layout().addWidget(config)
 
+    @Inputs.time_series
     def set_data(self, data):
         # TODO: set xAxis resolution and tooltip time contents depending on
         # data.time_delta. See: http://imgur.com/yrnlgQz
@@ -381,6 +386,7 @@ class OWLineChart(widget.OWWidget):
 
         self.data = data = None if data is None else Timeseries.from_data_table(data)
         if data is None:
+            self.varmodel.clear()
             self.chart.clear()
             return
         if getattr(data.time_variable, 'utc_offset', False):
@@ -395,11 +401,10 @@ class OWLineChart(widget.OWWidget):
                  getattr(data.time_variable, 'have_time', False))) else
             'linear')
 
-        self.varmodel.wrap([var for var in data.domain
+        self.varmodel.wrap([var for var in data.domain.variables
                             if var.is_continuous and var != data.time_variable])
-        self.chart.enable_rangeSelector(
-            isinstance(data.time_variable, TimeVariable))
 
+    @Inputs.forecast
     def set_forecast(self, forecast, id):
         if forecast is not None:
             self.forecasts[id] = forecast
@@ -409,18 +414,17 @@ class OWLineChart(widget.OWWidget):
 
 
 if __name__ == "__main__":
-    from PyQt4.QtGui import QApplication
+    from AnyQt.QtWidgets import QApplication
     from orangecontrib.timeseries import ARIMA, VAR
 
     a = QApplication([])
     ow = OWLineChart()
 
-    msft = Timeseries('yahoo_MSFT')
-    ow.set_data(msft),
-    # ow.set_data(Timeseries('UCI-SML2010-1'))
+    airpassengers = Timeseries('airpassengers')
+    ow.set_data(airpassengers),
 
-    msft = msft.interp()
-    model = ARIMA((3, 1, 1)).fit(msft)
+    msft = airpassengers.interp()
+    model = ARIMA((3, 1, 1)).fit(airpassengers)
     ow.set_forecast(model.predict(10, as_table=True), 0)
     model = VAR(4).fit(msft)
     ow.set_forecast(model.predict(10, as_table=True), 1)
