@@ -1,17 +1,15 @@
-import numpy as np
-
 from AnyQt.QtWidgets import QListView
 from AnyQt.QtCore import Qt
 
 from Orange.data import Table, Domain
 from Orange.widgets import widget, gui, settings
 from Orange.widgets.utils.itemmodels import VariableListModel
+from Orange.widgets.widget import Input, Output, Msg
 
 from orangecontrib.timeseries import Timeseries, seasonal_decompose
 
 
-class Output:
-    TIMESERIES = 'Time series'
+MAX_PERIODS = 1000
 
 
 class OWSeasonalAdjustment(widget.OWWidget):
@@ -21,8 +19,11 @@ class OWSeasonalAdjustment(widget.OWWidget):
     icon = 'icons/SeasonalAdjustment.svg'
     priority = 5500
 
-    inputs = [("Time series", Table, 'set_data')]
-    outputs = [("Time series", Timeseries)]
+    class Inputs:
+        time_series = Input("Time series", Table)
+
+    class Outputs:
+        time_series = Output("Time series", Timeseries)
 
     want_main_area = False
     resizing_enabled = False
@@ -52,10 +53,14 @@ class OWSeasonalAdjustment(widget.OWWidget):
 
     DECOMPOSITION_MODELS = ('additive', 'multiplicative')
 
+    class Error(widget.OWWidget.Error):
+        seasonal_decompose_fail = Msg("{}")
+        not_enough_instances = Msg("Time series has to have at least 3 instances.")
+
     def __init__(self):
         self.data = None
         box = gui.vBox(self.controlArea, 'Seasonal Adjustment')
-        gui.spin(box, self, 'n_periods', 2, 1000,
+        gui.spin(box, self, 'n_periods', 2, MAX_PERIODS,
                  label='Season period:',
                  callback=self.on_changed,
                  tooltip='The expected length of full cycle. E.g., if you have '
@@ -73,11 +78,21 @@ class OWSeasonalAdjustment(widget.OWWidget):
         box.layout().addWidget(view)
         gui.auto_commit(box, self, 'autocommit', '&Apply')
 
+    @Inputs.time_series
     def set_data(self, data):
-        self.data = data = None if data is None else Timeseries.from_data_table(data)
-        if data is not None:
-            self.model.wrap([var for var in data.domain
+        self.Error.not_enough_instances.clear()
+        self.data = None
+        self.model.clear()
+        data = None if data is None else Timeseries.from_data_table(data)
+        if data is None:
+            pass
+        elif len(data) > 2:
+            self.data = data
+            self.model.wrap([var for var in data.domain.variables
                              if var.is_continuous and var is not data.time_variable])
+            self.controls.n_periods.setMaximum(min(MAX_PERIODS, len(data) - 1))
+        else:
+            self.Error.not_enough_instances()
         self.on_changed()
 
     def on_changed(self):
@@ -86,23 +101,31 @@ class OWSeasonalAdjustment(widget.OWWidget):
         self.commit()
 
     def commit(self):
+        self.Error.seasonal_decompose_fail.clear()
         data = self.data
         if not data or not self.selected:
-            self.send(Output.TIMESERIES, data)
+            self.Outputs.time_series.send(data)
             return
 
         selected_subset = Timeseries(Domain(self.selected, source=data.domain), data)  # FIXME: might not pass selected interpolation method
 
         with self.progressBar(len(self.selected)) as progress:
-            adjusted_data = seasonal_decompose(
-                selected_subset,
-                self.DECOMPOSITION_MODELS[self.decomposition],
-                self.n_periods,
-                callback=lambda *_: progress.advance())
+            try:
+                adjusted_data = seasonal_decompose(
+                    selected_subset,
+                    self.DECOMPOSITION_MODELS[self.decomposition],
+                    self.n_periods,
+                    callback=lambda *_: progress.advance())
+            except ValueError as ex:
+                self.Error.seasonal_decompose_fail(str(ex))
+                adjusted_data = None
 
-        ts = Timeseries(Timeseries.concatenate((data, adjusted_data)))
-        ts.time_variable = data.time_variable
-        self.send(Output.TIMESERIES, ts)
+        if adjusted_data is not None:
+            ts = Timeseries(Timeseries.concatenate((data, adjusted_data)))
+            ts.time_variable = data.time_variable
+        else:
+            ts = None
+        self.Outputs.time_series.send(ts)
 
 
 if __name__ == "__main__":
@@ -111,7 +134,6 @@ if __name__ == "__main__":
     a = QApplication([])
     ow = OWSeasonalAdjustment()
 
-    # data = Timeseries('yahoo_MSFT')
     data = Timeseries('airpassengers')
     if not data.domain.class_var and 'Adj Close' in data.domain:
         # Make Adjusted Close a class variable
