@@ -1,6 +1,5 @@
 from contextlib import contextmanager
 
-import numpy as np
 import operator
 from collections import OrderedDict
 
@@ -9,6 +8,7 @@ from AnyQt.QtCore import QDateTime, Qt, QSize, QTimer
 
 from Orange.data import Table, TimeVariable
 from Orange.widgets import widget, gui, settings
+from Orange.widgets.widget import Input, Output
 
 from orangecontrib.timeseries import Timeseries
 from orangecontrib.timeseries.widgets._rangeslider import ViolinSlider
@@ -62,12 +62,11 @@ class OWTimeSlice(widget.OWWidget):
     icon = 'icons/TimeSlice.svg'
     priority = 550
 
-    inputs = [
-        ('Data', Table, 'set_data'),
-    ]
-    outputs = [
-        ('Subset', Table)
-    ]
+    class Inputs:
+        data = Input("Data", Table)
+
+    class Outputs:
+        subset = Output("Subset", Table)
 
     want_main_area = False
 
@@ -165,6 +164,7 @@ class OWTimeSlice(widget.OWWidget):
                                        autoDefault=False)
 
         gui.rubber(self.controlArea)
+        self._set_disabled(True)
 
     def valuesChanged(self, minValue, maxValue):
         self.slider_values = (minValue, maxValue)
@@ -187,7 +187,7 @@ class OWTimeSlice(widget.OWWidget):
         except AttributeError:
             return
         indices = (minTime <= time_values) & (time_values <= maxTime)
-        self.send('Subset', self.data[indices] if indices.any() else None)
+        self.Outputs.subset.send(self.data[indices] if indices.any() else None)
 
     def playthrough(self):
         playing = self.play_button.isChecked()
@@ -238,6 +238,14 @@ class OWTimeSlice(widget.OWWidget):
         self.valuesChanged(self.slider.minimumValue(), self.slider.maximumValue())
         self._delta = orig_delta  # Override valuesChanged handler
 
+    def _set_disabled(self, is_disabled):
+        for func in [self.date_from, self.date_to, self.step_backward, self.play_button,
+                     self.step_forward, self.controls.loop_playback,
+                     self.controls.steps_overlap, self.controls.overlap_amount,
+                     self.controls.playback_interval, self.slider]:
+            func.setDisabled(is_disabled)
+
+    @Inputs.data
     def set_data(self, data):
         slider = self.slider
         self.data = data = None if data is None else Timeseries.from_data_table(data)
@@ -247,8 +255,8 @@ class OWTimeSlice(widget.OWWidget):
             slider.setHistogram(None)
             slider.setScale(0, 0)
             slider.setValues(0, 0)
-            slider.setDisabled(True)
-            self.send('Subset', None)
+            self._set_disabled(True)
+            self.Outputs.subset.send(None)
 
         if data is None:
             disabled()
@@ -263,7 +271,7 @@ class OWTimeSlice(widget.OWWidget):
 
         time_values = data.time_values
 
-        slider.setDisabled(False)
+        self._set_disabled(False)
         slider.setHistogram(time_values)
         slider.setFormatter(var.repr_val)
         slider.setScale(time_values.min(), time_values.max())
@@ -284,7 +292,7 @@ if __name__ == '__main__':
     from AnyQt.QtWidgets import QApplication
     app = QApplication([])
     w = OWTimeSlice()
-    data = Table('/tmp/airpassengers.csv')
+    data = Table('airpassengers')
     w.set_data(data)
     w.show()
     app.exec()
